==> gpredict_0.4.0.orig.tar.gz: gpredict-0.4.0/src/toolbar.c <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
  toolbar.c: Horizontal toolbar for Gnome Predict.

  Copyright (C)  2001-2003  Alexandru Csete.

  Authors:  Alexandru Csete <csete@users.sourceforge.net>


  Comments, questions and bugreports should be submitted via
  http://sourceforge.net/projects/groundstation/
  More details can be found at http://groundstation.sourceforge.net/
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the
          Free Software Foundation, Inc.,
	  59 Temple Place, Suite 330,
	  Boston, MA  02111-1307
	  USA
*/

#include <gnome.h>
#include "satpref.h"
#include "callbacks.h"

#ifdef HAVE_CONFIG_H
#include "../config.h"
#endif


GnomeUIInfo toolbar[] = {
	GNOMEUIINFO_ITEM_STOCK (NULL,_("Quit Program"),
				gtk_main_quit,
				GNOME_STOCK_PIXMAP_EXIT),
	GNOMEUIINFO_SEPARATOR,
	GNOMEUIINFO_ITEM_STOCK (NULL, _("Edit preferences"),
				satpref_open_cb,
				GNOME_STOCK_PIXMAP_PREFERENCES ),
	GNOMEUIINFO_SEPARATOR,
	GNOMEUIINFO_ITEM_STOCK (NULL, _("Stop Tracking Engine"),
				timer_stop_callback,
				GNOME_STOCK_PIXMAP_STOP),
	GNOMEUIINFO_ITEM_STOCK (NULL, _("Start Tracking Engine"),
				timer_start_callback,
				GNOME_STOCK_PIXMAP_FORWARD),
	GNOMEUIINFO_SEPARATOR,
	GNOMEUIINFO_END
};

==> gpredict_0.5.1.orig.tar.gz: gpredict-0.5.1/src/toolbar.c <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
  toolbar.c: Horizontal toolbar for Gnome Predict.

  Copyright (C)  2001-2005  Alexandru Csete.

  Authors:  Alexandru Csete <csete@users.sourceforge.net>


  Comments, questions and bugreports should be submitted via
  http://sourceforge.net/projects/groundstation/
  More details can be found at http://groundstation.sourceforge.net/
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the
          Free Software Foundation, Inc.,
	  59 Temple Place, Suite 330,
	  Boston, MA  02111-1307
	  USA
*/

#include <gnome.h>
#include "satpref.h"
#include "callbacks.h"

#ifdef HAVE_CONFIG_H
#include "../config.h"
#endif


GnomeUIInfo toolbar[] = {
	GNOMEUIINFO_ITEM_STOCK (NULL,
				N_("Quit Program"),
				gtk_main_quit,
				GNOME_STOCK_PIXMAP_EXIT),
	GNOMEUIINFO_SEPARATOR,
	GNOMEUIINFO_ITEM_STOCK (NULL,
				N_("Edit preferences"),
				satpref_open_cb,
				GNOME_STOCK_PIXMAP_PREFERENCES ),
	GNOMEUIINFO_SEPARATOR,
	GNOMEUIINFO_ITEM_STOCK (NULL,
				N_("Stop Tracking Engine"),
				timer_stop_callback,
				GNOME_STOCK_PIXMAP_STOP),
	GNOMEUIINFO_ITEM_STOCK (NULL,
				N_("Start Tracking Engine"),
				timer_start_callback,
				GNOME_STOCK_PIXMAP_FORWARD),
	GNOMEUIINFO_SEPARATOR,
	GNOMEUIINFO_END
};
